Tests - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Tests

Jinja2 tests are like function calls, and specifically designed to check a condition and return a boolean.

## Built-in tests

In addition to Jinja2’s built-in tests, Betty provides the following:

- `copyright_notice_plugin`

- `date_range`

- `end_of_life_event`

- `entity`

- `entity_plugin`

- `event_type_plugin`

- `gender_plugin`

- `has_file_references`

- `has_links`

- `image_supported_media_type`

- `license_plugin`

- `linked_data_dumpable`

- `persistent_entity_id`

- `place_type_plugin`

- `presence_role_plugin`

- `private`

- `public`

- `start_of_life_event`

- `subject_role`

- `user_facing_entity`

- `witness_role`